@@ -164,15 +164,11 @@ void LevelLoader::setLevelset(const QString& filename)
         throw SystemException(QStringLiteral("Can't open file %1").arg(filename));
     }
 
-    QString errorString;
-    int errorLine;
-    int errorColumn;
-    bool success = m_levelset->setContent( &file, false, &errorString, &errorLine, &errorColumn);
-
+    const QDomDocument::ParseResult parseResult = m_levelset->setContent(&file);
     file.close();
-    if (!success) {
+    if (!parseResult) {
         qCDebug(PICMIC_LOG) << QStringLiteral("Can't read levelset from %1 \nError: %2 in Line %3, Column %4")
-                              .arg(filename, errorString).arg(errorLine).arg(errorColumn);
+                              .arg(filename, parseResult.errorMessage).arg(parseResult.errorLine).arg(parseResult.errorColumn);
         m_valid = false;
     }
 }
